aboutsummaryrefslogtreecommitdiff
path: root/include
diff options
context:
space:
mode:
Diffstat (limited to 'include')
-rw-r--r--include/curl/curl.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/include/curl/curl.h b/include/curl/curl.h
index f5dd65d49..5b4ae469e 100644
--- a/include/curl/curl.h
+++ b/include/curl/curl.h
@@ -1763,8 +1763,8 @@ typedef enum {
CURLSSLOPT_* */
CINIT(PROXY_SSL_OPTIONS, LONG, 261),
- /* Name of socks proxy to use. */
- CINIT(SOCKS_PROXY, STRINGPOINT, 262),
+ /* Name of pre proxy to use. */
+ CINIT(PRE_PROXY, STRINGPOINT, 262),
/* The public key in DER form used to validate the proxy public key
this option is used only if PROXY_SSL_VERIFYPEER is true */